==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTTESTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTTESTPOINTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTTESTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTTESTPOINTID_Type", propOrder = {
    "testpointequipmentid",
    "testpointset",
    "sequencenumber"
})
public class EQUIPMENTTESTPOINTID_Type {

    @XmlElement(name = "TESTPOINTEQUIPMENTID", required = true)
    protected TESTPOINTEQUIPMENTID_Type testpointequipmentid;
    @XmlElement(name = "TESTPOINTSET", required = true)
    protected String testpointset;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Obtient la valeur de la propriété testpointequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link TESTPOINTEQUIPMENTID_Type }
     *     
     */
    public TESTPOINTEQUIPMENTID_Type getTESTPOINTEQUIPMENTID() {
        return testpointequipmentid;
    }

    /**
     * Définit la valeur de la propriété testpointequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link TESTPOINTEQUIPMENTID_Type }
     *     
     */
    public void setTESTPOINTEQUIPMENTID(TESTPOINTEQUIPMENTID_Type value) {
        this.testpointequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété testpointset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTESTPOINTSET() {
        return testpointset;
    }

    /**
     * Définit la valeur de la propriété testpointset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTESTPOINTSET(String value) {
        this.testpointset = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTTESTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTTESTPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTTESTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTTESTPOINTID_Type", propOrder = {
    "testpointequipmentid",
    "testpointset",
    "sequencenumber"
})
public class EQUIPMENTTESTPOINTID_Type {

    @XmlElement(name = "TESTPOINTEQUIPMENTID", required = true)
    protected TESTPOINTEQUIPMENTID_Type testpointequipmentid;
    @XmlElement(name = "TESTPOINTSET", required = true)
    protected String testpointset;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Gets the value of the testpointequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link TESTPOINTEQUIPMENTID_Type }
     *     
     */
    public TESTPOINTEQUIPMENTID_Type getTESTPOINTEQUIPMENTID() {
        return testpointequipmentid;
    }

    /**
     * Sets the value of the testpointequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TESTPOINTEQUIPMENTID_Type }
     *     
     */
    public void setTESTPOINTEQUIPMENTID(TESTPOINTEQUIPMENTID_Type value) {
        this.testpointequipmentid = value;
    }

    /**
     * Gets the value of the testpointset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTESTPOINTSET() {
        return testpointset;
    }

    /**
     * Sets the value of the testpointset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTESTPOINTSET(String value) {
        this.testpointset = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}
